pub enum Error {
VlqLeftover,
VlqNoValues,
VlqOverflow,
BadJson(Error),
BadSegmentSize(u32),
BadSourceReference(u32),
BadNameReference(u32),
}Variants
VlqLeftover
a VLQ string was malformed and data was left over
VlqNoValues
a VLQ string was empty and no values could be decoded.
VlqOverflow
The input encoded a number that didn’t fit into i64.
BadJson(Error)
serde_json parsing failure
BadSegmentSize(u32)
a mapping segment had an unsupported size
BadSourceReference(u32)
a reference to a non existing source was encountered
BadNameReference(u32)
a reference to a non existing name was encountered